summaryrefslogtreecommitdiffstats
path: root/kmail/kmstartup.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmstartup.cpp')
-rw-r--r--kmail/kmstartup.cpp16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmail/kmstartup.cpp b/kmail/kmstartup.cpp
index 264e4b05..b5b0680d 100644
--- a/kmail/kmstartup.cpp
+++ b/kmail/kmstartup.cpp
@@ -43,7 +43,7 @@
#include <unistd.h>
#include <tqfile.h>
-#undef Status // stupid X headers
+#undef tqStatus // stupid X headers
extern "C" {
@@ -165,7 +165,7 @@ void lockOrDie() {
// On linux with /proc we can even check that it's really kmail and not something else
char path_buffer[MAXPATHLEN + 1];
path_buffer[MAXPATHLEN] = 0;
- const TQString procPath = TQString("/proc/%1/exe").arg(oldPid);
+ const TQString procPath = TQString("/proc/%1/exe").tqarg(oldPid);
const int length = readlink (procPath.latin1(), path_buffer, MAXPATHLEN);
if ( length == -1 ) // not such pid
first_instance = true;
@@ -199,17 +199,17 @@ void lockOrDie() {
"this machine. Running %2 more than once "
"can cause the loss of mail. You should not start %1 "
"unless you are sure that it is not already running.")
- .arg( programName, programName );
+ .tqarg( programName, programName );
// TQString::arg( st ) only replaces the first occurrence of %1
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
// even think about changing the above to .arg( programName ).
else
msg = i18n("%1 seems to be running on another display on this "
"machine. Running %1 and %2 at the same "
"time can cause the loss of mail. You should not start %2 "
"unless you are sure that %1 is not running.")
- .arg( oldProgramName, programName );
+ .tqarg( oldProgramName, programName );
}
else {
if ( oldAppName == appName )
@@ -217,19 +217,19 @@ void lockOrDie() {
"than once can cause the loss of mail. You should not "
"start %1 on this computer unless you are sure that it is "
"not already running on %2.")
- .arg( programName, oldHostName );
+ .tqarg( programName, oldHostName );
else
msg = i18n("%1 seems to be running on %3. Running %1 and %2 at the "
"same time can cause the loss of mail. You should not "
"start %2 on this computer unless you are sure that %1 is "
"not running on %3.")
- .arg( oldProgramName, programName, oldHostName );
+ .tqarg( oldProgramName, programName, oldHostName );
}
KCursorSaver idle( KBusyPtr::idle() );
if ( KMessageBox::No ==
KMessageBox::warningYesNo( 0, msg, TQString(),
- i18n("Start %1").arg( programName ),
+ i18n("Start %1").tqarg( programName ),
i18n("Exit") ) ) {
exit(1);
}
@@ -199,17 +199,17 @@ void lockOrDie() {
// with st while TQString::arg( s1, s2 ) replacess all occurrences
// of %1 with s1 and all occurrences of %2 with s2. So don't
- // even think about changing the above to .arg( programName ).
+ // even think about changing the above to .tqarg( programName ).
else
msg = i18n("%1 seems to be running on another display on this "